# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	WeakRef module for perl 
Name:		perl-WeakRef
Version:	0.01
Release:	25.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/WeakRef
Source0:	https://cpan.metacpan.org/authors/id/L/LU/LUKKA/WeakRef-%{version}.tar.gz
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
# Test Suite
BuildRequires:	perl(blib)
BuildRequires:	perl(Devel::Peek)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

# Don't "provide" private Perl libs
%{?perl_default_filter}

%description
A patch to Perl 5.005_55 by the author implements a core API for weak
references. This module is a Perl-level interface to that API, allowing
weak references to be created in Perl.

A weak reference is just like an ordinary Perl reference except that
it isn't included in the reference count of the thing referred to.
This means that once all references to a particular piece of data are
weak, the piece of data is freed and all the weak references are set
to undef. This is particularly useful for implementing circular
data structures without memory leaks or caches of objects.

%prep
%setup -q -n WeakRef-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc README Changes
%{perl_vendorarch}/auto/WeakRef/
%{perl_vendorarch}/WeakRef.pm
%{_mandir}/man3/WeakRef.3*

%changelog
* Fri Jun 23 2023 Paul Howarth <paul@city-fan.org> - 0.01-25
- Use SPDX-format license tag

* Tue May 31 2022 Paul Howarth <paul@city-fan.org> - 0.01-24
- Perl 5.36 rebuild

* Fri May 21 2021 Paul Howarth <paul@city-fan.org> - 0.01-23
- Perl 5.34 rebuild

* Wed Jun 24 2020 Paul Howarth <paul@city-fan.org> - 0.01-22
- Perl 5.32 rebuild

* Thu May 30 2019 Paul Howarth <paul@city-fan.org> - 0.01-21
- Perl 5.30 rebuild

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 0.01-20
- Perl 5.28 rebuild

* Wed Mar 21 2018 Paul Howarth <paul@city-fan.org> - 0.01-19
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Sun Oct 16 2016 Paul Howarth <paul@city-fan.org> - 0.01-18
- BR: perl-generators where available
- Simplify find commands using -empty and -delete

* Fri Feb 26 2016 Paul Howarth <paul@city-fan.org> - 0.01-17
- Classify buildreqs by usage
- Drop %%defattr, redundant since rpm 4.4

* Tue Jun 12 2012 Paul Howarth <paul@city-fan.org> - 0.01-16
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Fri Jul  8 2011 Paul Howarth <paul@city-fan.org> - 0.01-15
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 0.01-14
- Rebuild for perl 5.12.1 in Rawhide

* Fri May 28 2010 Paul Howarth <paul@city-fan.org> - 0.01-13
- Fix dist tag for RHEL-6 Beta

* Fri Mar  5 2010 Paul Howarth <paul@city-fan.org> - 0.01-12
- Dist tag for Rawhide no longer needs special-casing

* Fri Oct  2 2009 Paul Howarth <paul@city-fan.org> - 0.01-11
- Use %%{?perl_default_filter} for provides filter

* Fri Mar  6 2009 Paul Howarth <paul@city-fan.org> - 0.01-10
- Filter out unwanted provides for perl shared objects
- Update to SLES-compatible dist tag macros

* Tue Mar 11 2008 Paul Howarth <paul@city-fan.org> - 0.01-9
- Clarify license as GPL version 1 or later, or Artistic (i.e. same as perl)

* Wed Jun  6 2007 Paul Howarth <paul@city-fan.org> - 0.01-8
- Fix dist tag for Fedora 7 onwards
- BuildRequire perl(ExtUtils::MakeMaker)
- Fix argument order for find with -depth

* Fri Sep  1 2006 Paul Howarth <paul@city-fan.org> - 0.01-7
- Fix distribution tags for development releases

* Tue Aug 15 2006 Paul Howarth <paul@city-fan.org> - 0.01-6
- Simplify distribution-detection
- Define %%{__id_u} in a more portable way
- Remove buildroot unconditionally in %%clean and %%install
- Don't bother with %%{__perl_version} and %%{__perl_package macros}
- Use search.cpan.org URLs
- Optimize handling of compiler optimization flags
- Don't use macros in build-time command paths, hardcode them instead

* Wed Jul 13 2005 Paul Howarth <paul@city-fan.org> - 0.01-5
- Fix Group and directory ownership issues

* Tue May 17 2005 Paul Howarth <paul@city-fan.org> - 0.01-4
- Rewrite spec file in (mainly) Fedora Extras style
- Include full URL for source
- Fix URL
- Use MODULE_COMPAT dependency style and remove explicit perl dependency
- Remove MANIFEST from %%doc

* Thu Apr 15 2004 Paul Howarth <paul@city-fan.org> - 0.01-3
- Added explicit perl dependency to ensure that an RPM built on a
  system with an updated version of perl (and hence having files
  installed in a place that a non-updated system won't find them)
  will not install on the non-updated system; in such cases, just
  rebuild from the source RPM
- Changed distribution-identifying macros for greater portability

* Mon Feb 16 2004 Paul Howarth <paul@city-fan.org> - 0.01-2
- Unified spec file for Red Hat and Fedora Core

* Tue Feb 10 2004 Paul Howarth <paul@city-fan.org> - 0.01-1.fc1
- Initial build
